@@ -12,10 +12,11 @@
 #include "korganizer.h"
 #include "korganizer_debug.h"
 #include "korganizer_options.h"
-#include <kcoreaddons_version.h>
-#if KCOREADDONS_VERSION < QT_VERSION_CHECK(6, 0, 0)
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
 #include "korgmigrateapplication.h"
 #endif
+#include <KConfig>
+#include <KConfigGroup>
 #include <KCrash>
 #include <KLocalizedString>
 
@@ -24,12 +25,14 @@
 #endif
 int main(int argc, char **argv)
 {
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
     QCoreApplication::setAttribute(Qt::AA_EnableHighDpiScaling, true);
     QCoreApplication::setAttribute(Qt::AA_UseHighDpiPixmaps, true);
+#endif
     KOrganizerApp app(argc, &argv);
     KCrash::initialize();
     KLocalizedString::setApplicationDomain("korganizer");
-#if KCOREADDONS_VERSION < QT_VERSION_CHECK(6, 0, 0)
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
     KOrgMigrateApplication migrate;
     migrate.migrate();
 #endif
@@ -60,5 +63,10 @@ int main(int argc, char **argv)
         kRestoreMainWindows<KOrganizer>();
     }
 
+    // information for the reminder daemon
+    KConfig cfg(QStringLiteral("defaultcalendarrc"));
+    KConfigGroup grp(&cfg, QStringLiteral("General"));
+    grp.writeEntry(QStringLiteral("ApplicationId"), QStringLiteral("org.kde.korganizer"));
+
     return app.exec();
 }
