@@ -7,15 +7,14 @@
   SPDX-License-Identifier: GPL-2.0-or-later WITH Qt-Commercial-exception-1.0
 */
 
-#ifndef KOPREFSDESIGNERFIELDS_H
-#define KOPREFSDESIGNERFIELDS_H
+#pragma once
 
 #include "kcmdesignerfields.h"
 
 class KOPrefsDesignerFields : public KCMDesignerFields
 {
 public:
-    explicit KOPrefsDesignerFields(QWidget *parent = nullptr);
+    explicit KOPrefsDesignerFields(QWidget *parent = nullptr, const QVariantList &args = {});
 
 protected:
     Q_REQUIRED_RESULT QString localUiDir() override;
@@ -25,4 +24,3 @@ protected:
     Q_REQUIRED_RESULT QString applicationName() override;
 };
 
-#endif // KOPREFSDESIGNERFIELDS_H
